@@ -18,12 +18,12 @@ from os.path import isfile, join
 
 def forg():
     VIDEOEXT = [".avi",".mp4",".mpeg",".m4v",".mov",".ogv",".ts",".webm",".3gp",".3g2",".wmv",".mkv"]
-    APPLICATIONSEXT = [".abw",".arc",".azw",".bin",".bz",".bz2",".csh",".dmg",".eot",".epub",".gz",".jar",".js",".json",".jsonld",".cda",".mpkg",".ogx",".ogg",".php",".rar",".sh",".swf",".tar",".vsd",".xhtml",".xls",".xlsx",".xml",".xul",".zip",".7z",".pkg",".pem",".pkpass"]
-    AUDIOEXT = [".aac",".mid",".midi",".mp3",".m4a",".oga",".opus",".wav",".weba",".wma",".m3u8"]
+    APPLICATIONSEXT = [".abw",".arc",".bin",".bz",".bz2",".csh",".dmg",".eot",".epub",".gz",".jar",".js",".json",".jsonld",".cda",".mpkg",".ogx",".ogg",".php",".rar",".sh",".swf",".tar",".vsd",".xhtml",".xls",".xlsx",".xml",".xul",".zip",".7z",".pkg",".pem",".pkpass"]
+    AUDIOEXT = [".aac",".mid",".midi",".mp3",".m4a",".oga",".ogg",".opus",".wav",".weba",".wma",".m3u8"]
     IMAGEEXT = [".bmp",".gif",".ico",".jpeg",".jpg",".JPG",".png",".svg",".tif",".tiff",".webp",".png",".dwg",".ai",".cdr",".psd"]
     FONTEXT = [".otf",".ttf",".woff",".woff2"]
     DOCUMENTEXT  = [".doc",".docx",".htm",".html",".ics",".odp",".ods",".odt",".pdf",".ppt",".pptx",".rtf",".txt",".ppsx",".notesairdropdocument",".xlsm",".torrent",".srt",".css",".csv",".mjs",".key",".pages"]
-    BOOKEXT = [".mobi",".azw3",".djvu"]
+    BOOKEXT = [".epub" ,".mobi",".azw3",".djvu", ".azw", ".azw3", ".kf8", ".kfx", ".ibooks", ".cbr", ".cbz"," .cb7", ".cbt", ".cba"]
     RECEITAEXT = [".rec",".dec",".dbk"]
     #data_dir = os.path.join(os.path.dirname(__file__), 'tests', 'data')
     
@@ -33,7 +33,7 @@ def forg():
     'image': IMAGEEXT,
     'font': FONTEXT,
     'document': DOCUMENTEXT,
-    'book': BOOKEXT,
+    'books': BOOKEXT,
     'receita':RECEITAEXT
     }
 
